@@ -3,10 +3,12 @@ import numpy as np
 from cloud2cloud import cloud2cloud
 
 
-def get_uv(n_azi, n_longi, matrix_form=False, lims_azi=(0., 1.),
-           lims_longi=(0., 1.)):
-    u, v = [arr.T for arr in np.meshgrid(np.linspace(*lims_azi, n_azi),
-                                         np.linspace(*lims_longi, n_longi))]
+def get_uv(n_axe_1, n_axe_2, matrix_form=False, lims_axe_1=(0., 1.),
+           lims_axe_2=(0., 1.)):
+    u, v = [arr.T for arr in np.meshgrid(
+        np.linspace(*lims_axe_1, n_axe_1),
+        np.linspace(*lims_axe_2, n_axe_2)
+    )]
 
     if matrix_form:
         return np.stack((u, v), axis=-1)
