@@ -4,7 +4,7 @@
 import numpy as np
 from scipy import interpolate
 
-from kokiy.shell_2d import Shell2D
+from kokiy.shell_2d import Shell2D, compute_normals_from_xyz
 
 MAX_SPLINE_ORDER = 3
 SPLINE_SMOOTHNESS = 0
@@ -88,39 +88,32 @@ class AxiShell(Shell2D):
         rot_angle = 0
         if self.angle_min is not None:
             rot_angle = 0.5 * self.angle + self.angle_min
+
         min_theta = (rot_angle - 0.5 * self.angle) * np.pi / 180
         max_theta = (rot_angle + 0.5 * self.angle) * np.pi / 180
         theta_vec = np.linspace(min_theta, max_theta, num=self.shape[0])
-        self.rad, self.theta = np.meshgrid(shell_crest[1], theta_vec)
+        rad, theta = np.meshgrid(shell_crest[1], theta_vec)
 
         # Compute xyz matrix of shape (n_azi, n_longi, 3)
         self.x = np.tile(shell_crest[0], (self.shape[0], 1))
-        self.y = self.rad * np.cos(self.theta)
-        self.z = self.rad * np.sin(self.theta)
+        self.y = rad * np.cos(theta)
+        self.z = rad * np.sin(theta)
 
-        # Compute x,y,z,r-normal matrix of shape (n_azi, n_longi)
-        xr_nml_1d = _compute_shellcrest_nml(shell_crest)
-        self.n_r = np.tile(xr_nml_1d[1], (self.shape[0], 1))
-        self.n_x = np.tile(xr_nml_1d[0], (self.shape[0], 1))
-        self.n_y = self.n_r * np.cos(self.theta)
-        self.n_z = self.n_r * np.sin(self.theta)
+        perio_u = False
+        if self.angle == 360.:
+            perio_u = True
+        self.n_x,self.n_y,self.n_z= compute_normals_from_xyz(self.x,self.y,self.z, perio_u=perio_u)
 
         # Compute du, dv matrix of shape (n_azi, n_longi)
         self.du = np.pad(np.sqrt(np.diff(self.x, axis=1) ** 2
-                                 + np.diff(self.rad, axis=1) ** 2),
+                                 + np.diff(rad, axis=1) ** 2),
                          ((0, 0), (1, 0)), 'edge')
-        self.dv = self.rad * np.pad(np.diff(self.theta, axis=0),
+        self.dv = rad * np.pad(np.diff(theta, axis=0),
                                     ((1, 0), (0, 0)), 'edge')
-
-        # Compute abs_curv array of shape (n_longi,)
-        self.abs_curv = self._compute_abs_curv(self.du)
-
+        
         # Compute weight intervals in u and v directions array of shape (n_transvers, n_longi)
         self.dwu, self.dwv = self._compute_weight_interv_adim(self.du, self.dv)
 
-        # Compute surface nodes array of shape (n_transvers, n_longi)
-        self.surf = self._compute_surf(self.dwu, self.dwv)
-
     def replicate(self, shape):
         """Creates a similar instance, but possibly with different shape.
         """
@@ -144,14 +137,4 @@ def _compute_shell_crest(ctrl_pts_1, ctrl_pts_2, n):
     # Numpy Array of dim (2, self.shape[1]) [x,r] / [x,y]
     shell_crest = np.asarray(interpolate.splev(unew, tck))
 
-    return shell_crest
-
-
-def _compute_shellcrest_nml(shell_crest):
-    """Computes shell crest normals.
-    """
-    nml_vect = np.roll(np.diff(shell_crest), 1, axis=0)
-    nml_vect /= np.linalg.norm(nml_vect, axis=0)
-    nml_vect[0, :] *= -1
-    nml_vect = np.pad(nml_vect, ((0, 0), (0, 1)), mode='edge')
-    return nml_vect
+    return shell_crest
\ No newline at end of file
