@@ -3,7 +3,7 @@
 
 import numpy as np
 
-from kokiy.shell_2d import Shell2D
+from kokiy.shell_2d import Shell2D, compute_normals_from_xyz
 
 
 class CartShell(Shell2D):
@@ -66,46 +66,35 @@ class CartShell(Shell2D):
 
         vec_u = umax - zero
         vec_v = vmax - zero
+        self.x, self.y, self.z = _build_xyz(self.shape, zero, vec_u,vec_v)  
 
-        norm = np.cross(vec_u, vec_v)
-        norm /= np.linalg.norm(norm)
+        self.n_x,self.n_y,self.n_z= compute_normals_from_xyz(self.x,self.y,self.z)
 
-        u_range = np.linspace(0., 1., num=self.shape[0])
-        v_range = np.linspace(0., 1., num=self.shape[1])
+        # Surface element
         d_u = np.linalg.norm(vec_u) / (self.shape[0] - 1)
         d_v = np.linalg.norm(vec_v) / (self.shape[1] - 1)
-
-        v_coor, u_coor = np.meshgrid(v_range, u_range)
-        # multiply coord matrix by each vec component
-        u_coor = vec_u[:, np.newaxis, np.newaxis] * u_coor[np.newaxis, :, :]
-        v_coor = vec_v[:, np.newaxis, np.newaxis] * v_coor[np.newaxis, :, :]
-        xyz = np.stack([zero[i] + u_coor[i] + v_coor[i] for i in range(3)],
-                       axis=-1)
-        self.x, self.y, self.z = [np.take(xyz, i, -1) for i in range(3)]
-
-        # Compute radius and azimuth matrix of shape (n_transvers, n_longi)
-        self.rad = np.sqrt(self.y ** 2 + self.z ** 2)
-        self.theta = np.arctan2(self.z, self.y)
-
-        # Compute x,y,z,r-normal matrix of shape (n_transvers, n_longi)
-        self.n_x = np.full(self.shape, norm[0])
-        self.n_y = np.full(self.shape, norm[1])
-        self.n_z = np.full(self.shape, norm[2])
-        self.n_r = self.n_y * np.cos(self.theta)
-
         self.du = np.full(self.shape, d_u)
         self.dv = np.full(self.shape, d_v)
 
-        # Compute abs_curv array of shape (n_longi,)
-        self.abs_curv = self._compute_abs_curv(self.du)
-
         # Compute weight intervals in u and v directions array of shape (n_transvers, n_longi)
         self.dwu, self.dwv = self._compute_weight_interv_adim(self.du, self.dv)
-
-        # Compute surface nodoes array of shape (n_transvers, n_longi)
-        self.surf = self._compute_surf(self.dwu, self.dwv)
-
+    
     def replicate(self, shape):
         """Creates a similar instance, but possibly with different shape.
         """
         return CartShell(*shape, self.zero, self.umax, self.vmax)
+
+
+def _build_xyz(shape, zero, vec_u, vec_v):
+
+    u_range = np.linspace(0., 1., num=shape[0])
+    v_range = np.linspace(0., 1., num=shape[1])
+    
+    v_coor, u_coor = np.meshgrid(v_range, u_range)
+    # multiply coord matrix by each vec component
+    u_coor = vec_u[:, np.newaxis, np.newaxis] * u_coor[np.newaxis, :, :]
+    v_coor = vec_v[:, np.newaxis, np.newaxis] * v_coor[np.newaxis, :, :]
+    xyz = np.stack([zero[i] + u_coor[i] + v_coor[i] for i in range(3)],
+                    axis=-1)
+    x,y,z = [np.take(xyz, i, -1) for i in range(3)]
+    return x,y,z
\ No newline at end of file
