@@ -6,8 +6,8 @@ import numpy as np
 from arnica.utils.vector_actions import yz_to_theta
 from cloud2cloud import CloudInterpolator
 
-from kokiy import AxiShell
-from kokiy import CartShell
+from kokiy.axishell import AxiShell
+from kokiy.cartshell import CartShell
 
 # TODO: need to review how general this functions are
 
